==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/ElastiCache/DeleteCacheSecurityGroup.pm <==

package Paws::ElastiCache::DeleteCacheSecurityGroup {
  use Moose;
  has CacheSecurityGroupName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteCacheSecurityGroup');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::ElastiCache::DeleteCacheSecurityGroup - Arguments for method DeleteCacheSecurityGroup on Paws::ElastiCache

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteCacheSecurityGroup on the 
Amazon ElastiCache service. Use the attributes of this class
as arguments to method DeleteCacheSecurityGroup.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DeleteCacheSecurityGroup.

As an example:

  $service_obj->DeleteCacheSecurityGroup(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> CacheSecurityGroupName => Str

  

The name of the cache security group to delete.

You cannot delete the default security group.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for DeleteCacheSecurityGroup in Paws::ElastiCache

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.09.tar.gz: Paws-0.09/lib/Paws/ElastiCache/DeleteCacheSecurityGroup.pm <==

package Paws::ElastiCache::DeleteCacheSecurityGroup {
  use Moose;
  has CacheSecurityGroupName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteCacheSecurityGroup');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::ElastiCache::DeleteCacheSecurityGroup - Arguments for method DeleteCacheSecurityGroup on Paws::ElastiCache

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteCacheSecurityGroup on the 
Amazon ElastiCache service. Use the attributes of this class
as arguments to method DeleteCacheSecurityGroup.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DeleteCacheSecurityGroup.

As an example:

  $service_obj->DeleteCacheSecurityGroup(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> CacheSecurityGroupName => Str

  

The name of the cache security group to delete.

You cannot delete the default security group.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteCacheSecurityGroup in L<Paws::ElastiCache>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
